@@ -1,42 +1,26 @@
-# ATtila
-# Developed by Christian Visintin
-#
-# MIT License
-# Copyright (c) 2019 Christian Visintin
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-# The above copyright notice and this permission notice shall be included in all
-# copies or substantial portions of the Software.
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
-# SOFTWARE.
-#
-
 from attila.exceptions import ATSerialPortError
 from attila.virtual.virtualserial import VirtualSerial, VirtualSerialException
 from attila.atcommunicator import ATCommunicator
-import re
-from time import time
-from time import sleep
 from typing import Callable, Optional, List, Tuple
 
 
 class ATVirtualCommunicator(ATCommunicator):
     """
-    ATVirtualCommunicator class provides a virtual interface to communicate with an 
-    RF module using AT commands through a serial port 
+    ATVirtualCommunicator class provides a virtual interface to communicate with an
+    RF module using AT commands through a serial port
     This module should be used in test environment only
     """
 
-    def __init__(self, serial_port: str, baud_rate: int, default_timeout: int = 10, line_break: str = "\r\n", read_callback: Optional[Callable[[], str]] = None, write_callback: Optional[Callable[[str], None]] = None, in_waiting_callback: Optional[Callable[[], int]] = None):
+    def __init__(
+        self,
+        serial_port: str,
+        baud_rate: int,
+        default_timeout: int = 10,
+        line_break: str = "\r\n",
+        read_callback: Optional[Callable[[], str]] = None,
+        write_callback: Optional[Callable[[str], None]] = None,
+        in_waiting_callback: Optional[Callable[[], int]] = None,
+    ):
         """
         Class constructor. Instantiates a new :class:`.ATCommunicator.` object with the provided parameters.
 
@@ -58,7 +42,7 @@ class ATVirtualCommunicator(ATCommunicator):
         self._device = None
         self._serial_port = serial_port
         self._baud_rate = baud_rate
-        self.default_timeout = default_timeout
+        self.default_timeout: int = default_timeout
         self._line_break = line_break
         self.__writeCB = write_callback
         self.__readCB = read_callback
@@ -69,7 +53,7 @@ class ATVirtualCommunicator(ATCommunicator):
         return self._serial_port
 
     @serial_port.setter
-    def serial_port(self, serial_port):
+    def serial_port(self, serial_port: str):
         self._serial_port = serial_port
 
     @property
@@ -77,7 +61,7 @@ class ATVirtualCommunicator(ATCommunicator):
         return self._baud_rate
 
     @baud_rate.setter
-    def baud_rate(self, baud_rate):
+    def baud_rate(self, baud_rate: int):
         self._baud_rate = baud_rate
 
     @property
@@ -111,8 +95,14 @@ class ATVirtualCommunicator(ATCommunicator):
         if not self._serial_port:
             raise ATSerialPortError("Serial port is not set")
         try:
-            self._device = VirtualSerial(self._serial_port, self._baud_rate, timeout=0.5, read_callback=self.__readCB,
-                                         write_callback=self.__writeCB, in_waiting_callback=self.__inwaitingCB)
+            self._device = VirtualSerial(
+                self._serial_port,
+                self._baud_rate,
+                timeout=0.5,
+                read_callback=self.__readCB,
+                write_callback=self.__writeCB,
+                in_waiting_callback=self.__inwaitingCB,
+            )
         except (OSError, VirtualSerialException) as error:
             raise ATSerialPortError(error)
 
@@ -138,7 +128,9 @@ class ATVirtualCommunicator(ATCommunicator):
         """
         return super().is_open()
 
-    def exec(self, command: str, timeout: Optional[int] = None) -> Tuple[List[str], int]:
+    def exec(
+        self, command: str, timeout: Optional[int] = None
+    ) -> Tuple[List[str], int]:
         """
         Execute AT command
 
